@@ -1,6 +1,5 @@
 use solana_sdk::{
-    instruction::InstructionError, keyed_account::KeyedAccount, process_instruction::InvokeContext,
-    pubkey::Pubkey,
+    instruction::InstructionError, process_instruction::InvokeContext, pubkey::Pubkey,
 };
 
 solana_sdk::declare_program!(
@@ -11,7 +10,6 @@ solana_sdk::declare_program!(
 
 fn process_instruction(
     _program_id: &Pubkey,
-    _keyed_accounts: &[KeyedAccount],
     _data: &[u8],
     _invoke_context: &mut dyn InvokeContext,
 ) -> Result<(), InstructionError> {
